"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPixmap(QPaintDevice):
    """
    https://doc.qt.io/qt-6/qpixmap.html

    **Detailed Description**

    Qt provides four classes for handling image data: **QImage** , QPixmap,
    **QBitmap**  and **QPicture** . **QImage**  is designed and optimized for
    I/O, and for direct pixel access and manipulation, while QPixmap is designed
    and optimized for showing images on screen. **QBitmap**  is only a
    convenience class that inherits QPixmap, ensuring a depth of 1. The
    **isQBitmap** () function returns `true` if a QPixmap object is really a
    bitmap, otherwise returns `false`. Finally, the **QPicture**  class is a
    paint device that records and replays **QPainter**  commands.

    A QPixmap can easily be displayed on the screen using **QLabel**  or one of
    **QAbstractButton** 's subclasses (such as **QPushButton**  and
    **QToolButton** ). **QLabel**  has a pixmap property, whereas
    **QAbstractButton**  has an icon property.

    QPixmap objects can be passed around by value since the QPixmap class uses
    implicit data sharing. For more information, see the **Implicit Data
    Sharing**  documentation. QPixmap objects can also be streamed.

    Note that the pixel data in a pixmap is internal and is managed by the
    underlying window system. Because QPixmap is a **QPaintDevice**  subclass,
    **QPainter**  can be used to draw directly onto pixmaps. Pixels can only be
    accessed through **QPainter**  functions or by converting the QPixmap to a
    **QImage** . However, the **fill** () function is available for initializing
    the entire pixmap with a given color.

    There are functions to convert between **QImage**  and QPixmap. Typically,
    the **QImage**  class is used to load an image file, optionally manipulating
    the image data, before the **QImage**  object is converted into a QPixmap to
    be shown on screen. Alternatively, if no manipulation is desired, the image
    file can be loaded directly into a QPixmap.

    QPixmap provides a collection of functions that can be used to obtain a
    variety of information about the pixmap. In addition, there are several
    functions that enables transformation of the pixmap.

    **Reading and Writing Image Files**

    QPixmap provides several ways of reading an image file: The file can be
    loaded when constructing the QPixmap object, or by using the **load** () or
    **loadFromData** () functions later on. When loading an image, the file name
    can either refer to an actual file on disk or to one of the application's
    embedded resources. See **The Qt Resource System**  overview for details on
    how to embed images and other resource files in the application's
    executable.

    Simply call the **save** () function to save a QPixmap object.

    The complete list of supported file formats are available through the
    **QImageReader::supportedImageFormats** () and
    **QImageWriter::supportedImageFormats** () functions. New file formats can
    be added as plugins. By default, Qt supports the following formats:

    FormatDescriptionQt's support
    BMPWindows BitmapRead/write
    GIFGraphic
    Interchange Format (optional)Read
    JPGJoint Photographic Experts
    GroupRead/write
    JPEGJoint Photographic Experts GroupRead/write
    PNGPortable Network GraphicsRead/write
    PBMPortable BitmapRead
    PGMPortable GraymapRead
    PPMPortable PixmapRead/write
    XBMX11
    BitmapRead/write
    XPMX11 PixmapRead/write

    **Pixmap Information**

    QPixmap provides a collection of functions that can be used to obtain a
    variety of information about the pixmap:

    Available Functions
    GeometryThe **size** (), **width** () and **height**
    () functions provide information about the pixmap's size. The **rect** ()
    function returns the image's enclosing rectangle.
    Alpha componentThe
    **hasAlphaChannel** () returns `true` if the pixmap has a format that
    respects the alpha channel, otherwise returns `false`. The **hasAlpha** (),
    **setMask** () and **mask** () functions are legacy and should not be used.
    They are potentially very slow.

    The **createHeuristicMask** () function
    creates and returns a 1-bpp heuristic mask (i.e. a **QBitmap** ) for this
    pixmap. It works by selecting a color from one of the corners and then
    chipping away pixels of that color, starting at all the edges. The
    **createMaskFromColor** () function creates and returns a mask (i.e. a
    **QBitmap** ) for the pixmap based on a given color.

    Low-level
    informationThe **depth** () function returns the depth of the pixmap. The
    **defaultDepth** () function returns the default depth, i.e. the depth used
    by the application on the given screen.

    The **cacheKey** () function
    returns a number that uniquely identifies the contents of the QPixmap
    object.

    **Pixmap Conversion**

    A QPixmap object can be converted into a **QImage**  using the **toImage**
    () function. Likewise, a **QImage**  can be converted into a QPixmap using
    the **fromImage** (). If this is too expensive an operation, you can use
    **QBitmap::fromImage** () instead.

    To convert a QPixmap to and from HICON you can use the QtWinExtras functions
    QtWin::toHICON() and QtWin::fromHICON() respectively.

    **Pixmap Transformations**

    QPixmap supports a number of functions for creating a new pixmap that is a
    transformed version of the original:

    The **scaled** (), **scaledToWidth** () and **scaledToHeight** () functions
    return scaled copies of the pixmap, while the **copy** () function creates a
    QPixmap that is a plain copy of the original one.

    The **transformed** () function returns a copy of the pixmap that is
    transformed with the given transformation matrix and transformation mode:
    Internally, the transformation matrix is adjusted to compensate for unwanted
    translation, i.e. **transformed** () returns the smallest pixmap containing
    all transformed points of the original pixmap. The static **trueMatrix** ()
    function returns the actual matrix used for transforming the pixmap.

    **See also** **QBitmap** , **QImage** , **QImageReader** , and
    **QImageWriter** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap

        **QPixmap::QPixmap()**

        Constructs a null pixmap.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap-1

        **QPixmap::QPixmap(const QSize & size )**

        This is an overloaded function.

        Constructs a pixmap of the given **size**.

        **Warning:** This will create a QPixmap with uninitialized data. Call
        **fill** () to fill the pixmap with an appropriate color before drawing
        onto it with **QPainter** .
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap-2

        **QPixmap::QPixmap(const QString & fileName , const char * format =
        nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Constructs a pixmap from the file with the given **fileName**. If the
        file does not exist or is of an unknown format, the pixmap becomes a
        null pixmap.

        The loader attempts to read the pixmap using the specified **format**.
        If the **format** is not specified (which is the default), the loader
        probes the file for a header to guess the file format.

        The file name can either refer to an actual file on disk or to one of
        the application's embedded resources. See the **Resource System**
        overview for details on how to embed images and other resource files in
        the application's executable.

        If the image needs to be modified to fit in a lower-resolution result
        (e.g. converting from 32-bit to 8-bit), use the **flags** to control the
        conversion.

        The **fileName** , **format** and **flags** parameters are passed on to
        **load** (). This means that the data in **fileName** is not compiled
        into the binary. If **fileName** contains a relative path (e.g. the
        filename only) the relevant file must be found relative to the runtime
        working directory.

        **See also** **Reading and Writing Image Files** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        fileName: str,
        format: typing.Optional[str] = ...,
        flags: QtCore.Qt.ImageConversionFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap-3

        **QPixmap::QPixmap(const char *const [] xpm )**

        Constructs a pixmap from the given **xpm** data, which must be a valid
        XPM image.

        Errors are silently ignored.

        Note that it's possible to squeeze the XPM variable a little bit by
        using an unusual declaration:

        static const char * const start_xpm[] = {
                "16 15 8 1",
        "a c #cec6bd",
                // etc.
            };

        The extra `const` makes the entire definition read-only, which is
        slightly more efficient (for example, when the code is in a shared
        library) and ROMable when the application is to be stored in ROM.
        """
        ...

    @typing.overload
    def __init__(self, xpm: typing.List[str]) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap-4

        **QPixmap::QPixmap(const QPixmap & pixmap )**

        Constructs a pixmap that is a copy of the given **pixmap**.

        **See also** **copy** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPixmap") -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap-5

        **QPixmap::QPixmap(QPixmap && other )**

        Move-constructs a QPixmap instance from **other**.

        **See also** **swap** () and **operator=** (QPixmap&&).
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#QPixmap

        **QPixmap::QPixmap()**

        Constructs a null pixmap.

        **See also** **isNull** ().
        """
        ...

    def deviceIndependentSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qpixmap.html#deviceIndependentSize

        **QSizeF QPixmap::deviceIndependentSize() const**

        Returns the size of the pixmap in device independent pixels.

        This value should be used when using the pixmap size in user interface
        size calculations.

        The return value is equivalent to pixmap.**size** () /
        pixmap.**devicePixelRatio** (),
        """
        ...

    def setDevicePixelRatio(self, scaleFactor: float) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#setDevicePixelRatio

        **void QPixmap::setDevicePixelRatio(qreal scaleFactor )**

        Sets the device pixel ratio for the pixmap. This is the ratio between
        image pixels and device-independent pixels.

        The default **scaleFactor** is 1.0. Setting it to something else has two
        effects:

        QPainters that are opened on the pixmap will be scaled. For example,
        painting on a 200x200 image if with a ratio of 2.0 will result in
        effective (device-independent) painting bounds of 100x100.

        Code paths in Qt that calculate layout geometry based on the pixmap size
        will take the ratio into account: **QSize**  layoutSize =
        pixmap.**size** () / pixmap.**devicePixelRatio** () The net effect of
        this is that the pixmap is displayed as high-DPI pixmap rather than a
        large pixmap (see **Drawing High Resolution Versions of Pixmaps and
        Images** ).

        **See also** **devicePixelRatio** () and **deviceIndependentSize** ().
        """
        ...

    def devicePixelRatio(self) -> float:
        """
        https://doc.qt.io/qt-6/qpixmap.html#devicePixelRatio

        **qreal QPixmap::devicePixelRatio() const**

        Returns the device pixel ratio for the pixmap. This is the ratio between
        **device pixels** and **device independent pixels**.

        Use this function when calculating layout geometry based on the pixmap
        size: **QSize**  layoutSize = image.**size** () /
        image.devicePixelRatio()

        The default value is 1.0.

        **See also** **setDevicePixelRatio** () and **QImageReader** .
        """
        ...

    def swap(self, other: "QPixmap") -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#swap

        **void QPixmap::swap(QPixmap & other )**

        Swaps pixmap **other** with this pixmap. This operation is very fast and
        never fails.
        """
        ...

    @typing.overload
    def scroll(self, dx: int, dy: int, rect: QtCore.QRect) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qpixmap.html#scroll

        **void QPixmap::scroll(int dx , int dy , int x , int y , int width , int
        height , QRegion * exposed = nullptr)**

        This convenience function is equivalent to calling QPixmap::scroll(
        **dx** , **dy** , **QRect** ( **x** , **y** , **width** , **height** ),
        **exposed** ).

        **See also** **QWidget::scroll** () and **QGraphicsItem::scroll** ().
        """
        ...

    @typing.overload
    def scroll(
        self, dx: int, dy: int, x: int, y: int, width: int, height: int
    ) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qpixmap.html#scroll-1

        **void QPixmap::scroll(int dx , int dy , const QRect & rect , QRegion *
        exposed = nullptr)**

        Scrolls the area **rect** of this pixmap by ( **dx** , **dy** ). The
        exposed region is left unchanged. You can optionally pass a pointer to
        an empty **QRegion**  to get the region that is **exposed** by the
        scroll operation.

        **QPixmap**  pixmap("background.png");
            **QRegion**  exposed;
        pixmap.scroll(10, 10, pixmap.rect(), &exposed);

        You cannot scroll while there is an active painter on the pixmap.

        **See also** **QWidget::scroll** () and **QGraphicsItem::scroll** ().
        """
        ...

    def cacheKey(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixmap.html#cacheKey

        **qint64 QPixmap::cacheKey() const**

        Returns a number that identifies this **QPixmap** . Distinct **QPixmap**
        objects can only have the same cache key if they refer to the same
        contents.

        The cacheKey() will change when the pixmap is altered.
        """
        ...

    @staticmethod
    def trueMatrix(m: "QTransform", w: int, h: int) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qpixmap.html#trueMatrix

        **[static] QTransform QPixmap::trueMatrix(const QTransform & matrix ,
        int width , int height )**

        Returns the actual matrix used for transforming a pixmap with the given
        **width** , **height** and **matrix**.

        When transforming a pixmap using the **transformed** () function, the
        transformation matrix is internally adjusted to compensate for unwanted
        translation, i.e. **transformed** () returns the smallest pixmap
        containing all transformed points of the original pixmap. This function
        returns the modified matrix, which maps points correctly from the
        original pixmap into the new pixmap.

        **See also** **transformed** () and **Pixmap Transformations** .
        """
        ...

    def transformed(
        self, transform: "QTransform", mode: QtCore.Qt.TransformationMode = ...
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#transformed

        **QPixmap QPixmap::transformed(const QTransform & transform ,
        Qt::TransformationMode mode = Qt::FastTransformation) const**

        Returns a copy of the pixmap that is transformed using the given
        transformation **transform** and transformation **mode**. The original
        pixmap is not changed.

        The transformation **transform** is internally adjusted to compensate
        for unwanted translation; i.e. the pixmap produced is the smallest
        pixmap that contains all the transformed points of the original pixmap.
        Use the **trueMatrix** () function to retrieve the actual matrix used
        for transforming the pixmap.

        This function is slow because it involves transformation to a **QImage**
        , non-trivial computations and a transformation back to a **QPixmap** .

        **See also** **trueMatrix** () and **Pixmap Transformations** .
        """
        ...

    def metric(self, a0: QPaintDevice.PaintDeviceMetric) -> int:
        ...

    def paintEngine(self) -> "QPaintEngine":
        ...

    def isQBitmap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#isQBitmap

        **bool QPixmap::isQBitmap() const**

        Returns `true` if this is a **QBitmap** ; otherwise returns `false`.
        """
        ...

    def detach(self) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#detach

        **void QPixmap::detach()**

        Detaches the pixmap from shared pixmap data.

        A pixmap is automatically detached by Qt whenever its contents are about
        to change. This is done in almost all **QPixmap**  member functions that
        modify the pixmap (**fill** (), **fromImage** (), **load** (), etc.),
        and in **QPainter::begin** () on a pixmap.

        There are two exceptions in which detach() must be called explicitly,
        that is when calling the handle() or the x11PictureHandle() function
        (only available on X11). Otherwise, any modifications done using system
        calls, will be performed on the shared data.

        The detach() function returns immediately if there is just a single
        reference or if the pixmap has not been initialized yet.
        """
        ...

    @typing.overload
    def copy(self, rect: QtCore.QRect = ...) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#copy

        **QPixmap QPixmap::copy(const QRect & rectangle = QRect()) const**

        Returns a deep copy of the subset of the pixmap that is specified by the
        given **rectangle**. For more information on deep copies, see the
        **Implicit Data Sharing**  documentation.

        If the given **rectangle** is empty, the whole image is copied.

        **See also** **operator=** (), **QPixmap** (), and **Pixmap
        Transformations** .
        """
        ...

    @typing.overload
    def copy(self, ax: int, ay: int, awidth: int, aheight: int) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#copy-1

        **QPixmap QPixmap::copy(int x , int y , int width , int height ) const**

        This is an overloaded function.

        Returns a deep copy of the subset of the pixmap that is specified by the
        rectangle **QRect** ( **x** , **y** , **width** , **height** ).
        """
        ...

    @typing.overload
    def save(
        self, fileName: str, format: typing.Optional[str] = ..., quality: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#save

        **bool QPixmap::save(const QString & fileName , const char * format =
        nullptr, int quality = -1) const**

        Saves the pixmap to the file with the given **fileName** using the
        specified image file **format** and **quality** factor. Returns `true`
        if successful; otherwise returns `false`.

        The **quality** factor must be in the range [0,100] or -1. Specify 0 to
        obtain small compressed files, 100 for large uncompressed files, and -1
        to use the default settings.

        If **format** is `nullptr`, an image format will be chosen from
        **fileName** 's suffix.

        **See also** **Reading and Writing Image Files** .
        """
        ...

    @typing.overload
    def save(
        self,
        device: QtCore.QIODevice,
        format: typing.Optional[str] = ...,
        quality: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#save-1

        **bool QPixmap::save(QIODevice * device , const char * format = nullptr,
        int quality = -1) const**

        This is an overloaded function.

        This function writes a **QPixmap**  to the given **device** using the
        specified image file **format** and **quality** factor. This can be
        used, for example, to save a pixmap directly into a **QByteArray** :

        **QPixmap**  pixmap;
            **QByteArray**  bytes;
            **QBuffer**
        buffer(&bytes);
            buffer.open(**QIODevice** ::WriteOnly);
        pixmap.save(&buffer, "PNG"); // writes pixmap into bytes in PNG format
        """
        ...

    @typing.overload
    def loadFromData(
        self,
        buf: bytes,
        format: typing.Optional[str] = ...,
        flags: QtCore.Qt.ImageConversionFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#loadFromData

        **bool QPixmap::loadFromData(const uchar * data , uint len , const char
        * format = nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Loads a pixmap from the **len** first bytes of the given binary
        **data**. Returns `true` if the pixmap was loaded successfully;
        otherwise invalidates the pixmap and returns `false`.

        The loader attempts to read the pixmap using the specified **format**.
        If the **format** is not specified (which is the default), the loader
        probes the file for a header to guess the file format.

        If the data needs to be modified to fit in a lower-resolution result
        (e.g. converting from 32-bit to 8-bit), use the **flags** to control the
        conversion.

        **See also** **load** () and **Reading and Writing Image Files** .
        """
        ...

    @typing.overload
    def loadFromData(
        self,
        buf: QtCore.QByteArray,
        format: typing.Optional[str] = ...,
        flags: QtCore.Qt.ImageConversionFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#loadFromData-1

        **bool QPixmap::loadFromData(const QByteArray & data , const char *
        format = nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor)**

        This is an overloaded function.

        Loads a pixmap from the binary **data** using the specified **format**
        and conversion **flags**.
        """
        ...

    def load(
        self,
        fileName: str,
        format: typing.Optional[str] = ...,
        flags: QtCore.Qt.ImageConversionFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#load

        **bool QPixmap::load(const QString & fileName , const char * format =
        nullptr, Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Loads a pixmap from the file with the given **fileName**. Returns true
        if the pixmap was successfully loaded; otherwise invalidates the pixmap
        and returns `false`.

        The loader attempts to read the pixmap using the specified **format**.
        If the **format** is not specified (which is the default), the loader
        probes the file for a header to guess the file format.

        The file name can either refer to an actual file on disk or to one of
        the application's embedded resources. See the **Resource System**
        overview for details on how to embed pixmaps and other resource files in
        the application's executable.

        If the data needs to be modified to fit in a lower-resolution result
        (e.g. converting from 32-bit to 8-bit), use the **flags** to control the
        conversion.

        Note that QPixmaps are automatically added to the **QPixmapCache**  when
        loaded from a file in main thread; the key used is internal and cannot
        be acquired.

        **See also** **loadFromData** () and **Reading and Writing Image Files**
        .
        """
        ...

    def convertFromImage(
        self, img: "QImage", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#convertFromImage

        **bool QPixmap::convertFromImage(const QImage & image ,
        Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Replaces this pixmap's data with the given **image** using the specified
        **flags** to control the conversion. The **flags** argument is a
        bitwise-OR of the **Qt::ImageConversionFlags** . Passing 0 for **flags**
        sets all the default options. Returns `true` if the result is that this
        pixmap is not null.

        Note: this function was part of Qt 3 support in Qt 4.6 and earlier. It
        has been promoted to official API status in 4.7 to support updating the
        pixmap's image without creating a new **QPixmap**  as **fromImage** ()
        would.

        **See also** **fromImage** ().
        """
        ...

    @staticmethod
    def fromImageReader(
        imageReader: "QImageReader", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#fromImageReader

        **[static] QPixmap QPixmap::fromImageReader(QImageReader * imageReader ,
        Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Create a **QPixmap**  from an image read directly from an
        **imageReader**. The **flags** argument is a bitwise-OR of the
        **Qt::ImageConversionFlags** . Passing 0 for **flags** sets all the
        default options.

        On some systems, reading an image directly to **QPixmap**  can use less
        memory than reading a **QImage**  to convert it to **QPixmap** .

        **See also** **fromImage** (), **toImage** (), and **Pixmap Conversion**
        .
        """
        ...

    @staticmethod
    def fromImage(
        image: "QImage", flags: QtCore.Qt.ImageConversionFlag = ...
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#fromImage

        **[static] QPixmap QPixmap::fromImage(const QImage & image ,
        Qt::ImageConversionFlags flags = Qt::AutoColor)**

        Converts the given **image** to a pixmap using the specified **flags**
        to control the conversion. The **flags** argument is a bitwise-OR of the
        **Qt::ImageConversionFlags** . Passing 0 for **flags** sets all the
        default options.

        In case of monochrome and 8-bit images, the image is first converted to
        a 32-bit pixmap and then filled with the colors in the color table. If
        this is too expensive an operation, you can use **QBitmap::fromImage**
        () instead.

        **See also** **fromImageReader** (), **toImage** (), and **Pixmap
        Conversion** .
        """
        ...

    def toImage(self) -> "QImage":
        """
        https://doc.qt.io/qt-6/qpixmap.html#toImage

        **QImage QPixmap::toImage() const**

        Converts the pixmap to a **QImage** . Returns a null image if the
        conversion fails.

        If the pixmap has 1-bit depth, the returned image will also be 1 bit
        deep. Images with more bits will be returned in a format closely
        represents the underlying system. Usually this will be
        **QImage::Format_ARGB32_Premultiplied**  for pixmaps with an alpha and
        **QImage::Format_RGB32**  or **QImage::Format_RGB16**  for pixmaps
        without alpha.

        Note that for the moment, alpha masks on monochrome images are ignored.

        **See also** **fromImage** () and **Image Formats** .
        """
        ...

    def scaledToHeight(
        self, height: int, mode: QtCore.Qt.TransformationMode = ...
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#scaledToHeight

        **QPixmap QPixmap::scaledToHeight(int height , Qt::TransformationMode
        mode = Qt::FastTransformation) const**

        Returns a scaled copy of the image. The returned image is scaled to the
        given **height** using the specified transformation **mode**. The width
        of the pixmap is automatically calculated so that the aspect ratio of
        the pixmap is preserved.

        If **height** is 0 or negative, a null pixmap is returned.

        **See also** **isNull** () and **Pixmap Transformations** .
        """
        ...

    def scaledToWidth(
        self, width: int, mode: QtCore.Qt.TransformationMode = ...
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#scaledToWidth

        **QPixmap QPixmap::scaledToWidth(int width , Qt::TransformationMode mode
        = Qt::FastTransformation) const**

        Returns a scaled copy of the image. The returned image is scaled to the
        given **width** using the specified transformation **mode**. The height
        of the pixmap is automatically calculated so that the aspect ratio of
        the pixmap is preserved.

        If **width** is 0 or negative, a null pixmap is returned.

        **See also** **isNull** () and **Pixmap Transformations** .
        """
        ...

    @typing.overload
    def scaled(
        self,
        width: int,
        height: int,
        aspectRatioMode: QtCore.Qt.AspectRatioMode = ...,
        transformMode: QtCore.Qt.TransformationMode = ...,
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#scaled

        **QPixmap QPixmap::scaled(const QSize & size , Qt::AspectRatioMode
        aspectRatioMode = Qt::IgnoreAspectRatio, Qt::TransformationMode
        transformMode = Qt::FastTransformation) const**

        Scales the pixmap to the given **size** , using the aspect ratio and
        transformation modes specified by **aspectRatioMode** and
        **transformMode**.

        ![](images/qimage-scaling.png)

        * If **aspectRatioMode** is **Qt::IgnoreAspectRatio** , the pixmap is
        scaled to **size**.
          * If **aspectRatioMode** is
        **Qt::KeepAspectRatio** , the pixmap is scaled to a rectangle as large
        as possible inside **size** , preserving the aspect ratio.
          * If
        **aspectRatioMode** is **Qt::KeepAspectRatioByExpanding** , the pixmap
        is scaled to a rectangle as small as possible outside **size** ,
        preserving the aspect ratio.

        If the given **size** is empty, this function returns a null pixmap.

        In some cases it can be more beneficial to draw the pixmap to a painter
        with a scale set rather than scaling the pixmap. This is the case when
        the painter is for instance based on OpenGL or when the scale factor
        changes rapidly.

        **See also** **isNull** () and **Pixmap Transformations** .
        """
        ...

    @typing.overload
    def scaled(
        self,
        size: QtCore.QSize,
        aspectRatioMode: QtCore.Qt.AspectRatioMode = ...,
        transformMode: QtCore.Qt.TransformationMode = ...,
    ) -> "QPixmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#scaled-1

        **QPixmap QPixmap::scaled(int width , int height , Qt::AspectRatioMode
        aspectRatioMode = Qt::IgnoreAspectRatio, Qt::TransformationMode
        transformMode = Qt::FastTransformation) const**

        This is an overloaded function.

        Returns a copy of the pixmap scaled to a rectangle with the given
        **width** and **height** according to the given **aspectRatioMode** and
        **transformMode**.

        If either the **width** or the **height** is zero or negative, this
        function returns a null pixmap.
        """
        ...

    def createMaskFromColor(
        self,
        maskColor: typing.Union["QColor", QtCore.Qt.GlobalColor, int],
        mode: QtCore.Qt.MaskMode = ...,
    ) -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#createMaskFromColor

        **QBitmap QPixmap::createMaskFromColor(const QColor & maskColor ,
        Qt::MaskMode mode = Qt::MaskInColor) const**

        Creates and returns a mask for this pixmap based on the given
        **maskColor**. If the **mode** is **Qt::MaskInColor** , all pixels
        matching the maskColor will be transparent. If **mode** is
        **Qt::MaskOutColor** , all pixels matching the maskColor will be opaque.

        This function is slow because it involves converting to/from a
        **QImage** .

        **See also** **createHeuristicMask** () and
        **QImage::createMaskFromColor** ().
        """
        ...

    def createHeuristicMask(self, clipTight: bool = ...) -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#createHeuristicMask

        **QBitmap QPixmap::createHeuristicMask(bool clipTight = true) const**

        Creates and returns a heuristic mask for this pixmap.

        The function works by selecting a color from one of the corners and then
        chipping away pixels of that color, starting at all the edges. If
        **clipTight** is true (the default) the mask is just large enough to
        cover the pixels; otherwise, the mask is larger than the data pixels.

        The mask may not be perfect but it should be reasonable, so you can do
        things such as the following:

        **QPixmap**  myPixmap;
        myPixmap.setMask(myPixmap.createHeuristicMask());

        This function is slow because it involves converting to/from a
        **QImage** , and non-trivial computations.

        **See also** **QImage::createHeuristicMask** () and
        **createMaskFromColor** ().
        """
        ...

    def hasAlphaChannel(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#hasAlphaChannel

        **bool QPixmap::hasAlphaChannel() const**

        Returns `true` if the pixmap has a format that respects the alpha
        channel, otherwise returns `false`.

        **See also** **hasAlpha** ().
        """
        ...

    def hasAlpha(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#hasAlpha

        **bool QPixmap::hasAlpha() const**

        Returns `true` if this pixmap has an alpha channel, **or** has a mask,
        otherwise returns `false`.

        **See also** **hasAlphaChannel** () and **mask** ().
        """
        ...

    def setMask(self, a0: "QBitmap") -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#setMask

        **void QPixmap::setMask(const QBitmap & mask )**

        Sets a mask bitmap.

        This function merges the **mask** with the pixmap's alpha channel. A
        pixel value of 1 on the mask means the pixmap's pixel is unchanged; a
        value of 0 means the pixel is transparent. The mask must have the same
        size as this pixmap.

        Setting a null mask resets the mask, leaving the previously transparent
        pixels black. The effect of this function is undefined when the pixmap
        is being painted on.

        **Warning:** This is potentially an expensive operation.

        **See also** **mask** (), **Pixmap Transformations** , and **QBitmap** .
        """
        ...

    def mask(self) -> "QBitmap":
        """
        https://doc.qt.io/qt-6/qpixmap.html#mask

        **QBitmap QPixmap::mask() const**

        Extracts a bitmap mask from the pixmap's alpha channel.

        **Warning:** This is potentially an expensive operation. The mask of the
        pixmap is extracted dynamically from the pixeldata.

        **See also** **setMask** () and **Pixmap Information** .
        """
        ...

    def fill(
        self, color: typing.Union["QColor", QtCore.Qt.GlobalColor, int] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpixmap.html#fill

        **void QPixmap::fill(const QColor & color = Qt::white)**

        Fills the pixmap with the given **color**.

        The effect of this function is undefined when the pixmap is being
        painted on.

        **See also** **Pixmap Transformations** .
        """
        ...

    @staticmethod
    def defaultDepth() -> int:
        """
        https://doc.qt.io/qt-6/qpixmap.html#defaultDepth

        **[static] int QPixmap::defaultDepth()**

        Returns the default pixmap depth used by the application.

        On all platforms the depth of the primary screen will be returned.

        **Note:****QGuiApplication**  must be created before calling this
        function.

        **See also** **depth** (), **QColormap::depth** (), and **Pixmap
        Information** .
        """
        ...

    def depth(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixmap.html#depth

        **int QPixmap::depth() const**

        Returns the depth of the pixmap.

        The pixmap depth is also called bits per pixel (bpp) or bit planes of a
        pixmap. A null pixmap has depth 0.

        **See also** **defaultDepth** () and **Pixmap Information** .
        """
        ...

    def rect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpixmap.html#rect

        **QRect QPixmap::rect() const**

        Returns the pixmap's enclosing rectangle.

        **See also** **Pixmap Information** .
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpixmap.html#size

        **QSize QPixmap::size() const**

        Returns the size of the pixmap.

        **See also** **width** (), **height** (), and **Pixmap Information** .
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixmap.html#height

        **int QPixmap::height() const**

        Returns the height of the pixmap.

        **See also** **size** () and **Pixmap Information** .
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qpixmap.html#width

        **int QPixmap::width() const**

        Returns the width of the pixmap.

        **See also** **size** () and **Pixmap Information** .
        """
        ...

    def devType(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpixmap.html#isNull

        **bool QPixmap::isNull() const**

        Returns `true` if this is a null pixmap; otherwise returns `false`.

        A null pixmap has zero width, zero height and no contents. You cannot
        draw in a null pixmap.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QMainWindow(QWidget):
    """
    https://doc.qt.io/qt-6/qmainwindow.html

    **Detailed Description**

    **Qt Main Window Framework**

    A main window provides a framework for building an application's user
    interface. Qt has QMainWindow and its **related classes**  for main window
    management. QMainWindow has its own layout to which you can add **QToolBar**
    s, **QDockWidget** s, a **QMenuBar** , and a **QStatusBar** . The layout has
    a center area that can be occupied by any kind of widget. You can see an
    image of the layout below.

    ![](images/mainwindowlayout.png)

    **Note:** Creating a main window without a central widget is not supported.
    You must have a central widget even if it is just a placeholder.

    **Creating Main Window Components**

    A central widget will typically be a standard Qt widget such as a
    **QTextEdit**  or a **QGraphicsView** . Custom widgets can also be used for
    advanced applications. You set the central widget with `setCentralWidget()`.

    Main windows have either a single (SDI) or multiple (MDI) document
    interface. You create MDI applications in Qt by using a **QMdiArea**  as the
    central widget.

    We will now examine each of the other widgets that can be added to a main
    window. We give examples on how to create and add them.

    **Creating Menus**

    Qt implements menus in **QMenu**  and QMainWindow keeps them in a
    **QMenuBar** . **QAction** s are added to the menus, which display them as
    menu items.

    You can add new menus to the main window's menu bar by calling `menuBar()`,
    which returns the **QMenuBar**  for the window, and then add a menu with
    **QMenuBar::addMenu** ().

    QMainWindow comes with a default menu bar, but you can also set one yourself
    with `setMenuBar()`. If you wish to implement a custom menu bar (i.e., not
    use the **QMenuBar**  widget), you can set it with `setMenuWidget()`.

    An example of how to create menus follows:

    void MainWindow::createMenus()
            {
                fileMenu =
    menuBar()->addMenu(tr("&File"));
                fileMenu->addAction(newAct);
    fileMenu->addAction(openAct);
                fileMenu->addAction(saveAct);

    The `createPopupMenu()` function creates popup menus when the main window
    receives context menu events. The default implementation generates a menu
    with the checkable actions from the dock widgets and toolbars. You can
    reimplement `createPopupMenu()` for a custom menu.

    **Creating Toolbars**

    Toolbars are implemented in the **QToolBar**  class. You add a toolbar to a
    main window with `addToolBar()`.

    You control the initial position of toolbars by assigning them to a specific
    **Qt::ToolBarArea** . You can split an area by inserting a toolbar break -
    think of this as a line break in text editing - with `addToolBarBreak()` or
    `insertToolBarBreak()`. You can also restrict placement by the user with
    **QToolBar::setAllowedAreas** () and **QToolBar::setMovable** ().

    The size of toolbar icons can be retrieved with `iconSize()`. The sizes are
    platform dependent; you can set a fixed size with `setIconSize()`. You can
    alter the appearance of all tool buttons in the toolbars with
    `setToolButtonStyle()`.

    An example of toolbar creation follows:

    void MainWindow::createToolBars()
            {
                fileToolBar =
    addToolBar(tr("File"));
                fileToolBar->addAction(newAct);

    **Creating Dock Widgets**

    Dock widgets are implemented in the **QDockWidget**  class. A dock widget is
    a window that can be docked into the main window. You add dock widgets to a
    main window with `addDockWidget()`.

    There are four dock widget areas as given by the **Qt::DockWidgetArea**
    enum: left, right, top, and bottom. You can specify which dock widget area
    that should occupy the corners where the areas overlap with `setCorner()`.
    By default each area can only contain one row (vertical or horizontal) of
    dock widgets, but if you enable nesting with `setDockNestingEnabled()`, dock
    widgets can be added in either direction.

    Two dock widgets may also be stacked on top of each other. A **QTabBar**  is
    then used to select which of the widgets should be displayed.

    We give an example of how to create and add dock widgets to a main window:

    **QDockWidget**  *dockWidget = new **QDockWidget** (tr("Dock Widget"),
    this);
            dockWidget->setAllowedAreas(Qt::LeftDockWidgetArea |
    Qt::RightDockWidgetArea);
            dockWidget->setWidget(dockWidgetContents);
    addDockWidget(Qt::LeftDockWidgetArea, dockWidget);

    **The Status Bar**

    You can set a status bar with `setStatusBar()`, but one is created the first
    time `statusBar()` (which returns the main window's status bar) is called.
    See **QStatusBar**  for information on how to use it.

    **Storing State**

    QMainWindow can store the state of its layout with `saveState()`; it can
    later be retrieved with `restoreState()`. It is the position and size
    (relative to the size of the main window) of the toolbars and dock widgets
    that are stored.

    **See also** **QMenuBar** , **QToolBar** , **QStatusBar** , **QDockWidget**
    , **Qt Widgets - Application Example** , **Dock Widgets Example** , **MDI
    Example** , **SDI Example** , and **Menus Example** .
    """

    class DockOption(enum.Flag):
        AnimatedDocks: QMainWindow = ...
        AllowNestedDocks: QMainWindow = ...
        AllowTabbedDocks: QMainWindow = ...
        ForceTabbedDocks: QMainWindow = ...
        VerticalTabs: QMainWindow = ...
        GroupedDragging: QMainWindow = ...

    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#QMainWindow

        **QMainWindow::QMainWindow(QWidget * parent = nullptr, Qt::WindowFlags
        flags = Qt::WindowFlags())**

        Constructs a QMainWindow with the given **parent** and the specified
        widget **flags**.

        QMainWindow sets the **Qt::Window**  flag itself, and will hence always
        be created as a top-level widget.
        """
        ...

    def resizeDocks(
        self,
        docks: typing.Iterable[QDockWidget],
        sizes: typing.Iterable[int],
        orientation: QtCore.Qt.Orientation,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#resizeDocks

        **[since 5.6] void QMainWindow::resizeDocks(const QList<QDockWidget *> &
        docks , const QList<int> & sizes , Qt::Orientation orientation )**

        Resizes the dock widgets in the list **docks** to the corresponding size
        in pixels from the list **sizes**. If **orientation** is
        **Qt::Horizontal** , adjusts the width, otherwise adjusts the height of
        the dock widgets. The sizes will be adjusted such that the maximum and
        the minimum sizes are respected and the **QMainWindow**  itself will not
        be resized. Any additional/missing space is distributed amongst the
        widgets according to the relative weight of the sizes.

        Example:

        resizeDocks({blueWidget, yellowWidget}, {20 , 40}, Qt::Horizontal);

        If the blue and the yellow widget are nested on the same level they will
        be resized such that the yellowWidget is twice as big as the blueWidget

        If some widgets are grouped in tabs, only one widget per group should be
        specified. Widgets not in the list might be changed to respect the
        constraints.

        This function was introduced in Qt 5.6.
        """
        ...

    def takeCentralWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#takeCentralWidget

        **[since 5.2] QWidget *QMainWindow::takeCentralWidget()**

        Removes the central widget from this main window.

        The ownership of the removed widget is passed to the caller.

        This function was introduced in Qt 5.2.
        """
        ...

    def tabifiedDockWidgets(self, dockwidget: QDockWidget) -> typing.List[QDockWidget]:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#tabifiedDockWidgets

        **QList<QDockWidget *> QMainWindow::tabifiedDockWidgets(QDockWidget *
        dockwidget ) const**

        Returns the dock widgets that are tabified together with **dockwidget**.

        **See also** **tabifyDockWidget** ().
        """
        ...

    def setTabPosition(
        self, areas: QtCore.Qt.DockWidgetArea, tabPosition: "QTabWidget.TabPosition"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#setTabPosition

        **void QMainWindow::setTabPosition(Qt::DockWidgetAreas areas ,
        QTabWidget::TabPosition tabPosition )**

        Sets the tab position for the given dock widget **areas** to the
        specified **tabPosition**. By default, all dock areas show their tabs at
        the bottom.

        **Note:** The **VerticalTabs**  dock option overrides the tab positions
        set by this method.

        **See also** **tabPosition** () and **setTabShape** ().
        """
        ...

    def tabPosition(self, area: QtCore.Qt.DockWidgetArea) -> "QTabWidget.TabPosition":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#tabPosition

        **QTabWidget::TabPosition QMainWindow::tabPosition(Qt::DockWidgetArea
        area ) const**

        Returns the tab position for **area**.

        **Note:** The **VerticalTabs**  dock option overrides the tab positions
        returned by this function.

        **See also** **setTabPosition** () and **tabShape** ().
        """
        ...

    def setTabShape(self, tabShape: "QTabWidget.TabShape") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#tabShape-prop

        **tabShape : QTabWidget::TabShape**

        This property holds the tab shape used for tabbed dock widgets.

        The default is **QTabWidget::Rounded** .

        **Access functions:**

        QTabWidget::TabShape **tabShape** () const
        void **setTabShape**
        (QTabWidget::TabShape **tabShape** )

        **See also** **setTabPosition** ().
        """
        ...

    def tabShape(self) -> "QTabWidget.TabShape":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#tabShape-prop

        **tabShape : QTabWidget::TabShape**

        This property holds the tab shape used for tabbed dock widgets.

        The default is **QTabWidget::Rounded** .

        **Access functions:**

        QTabWidget::TabShape **tabShape** () const
        void **setTabShape**
        (QTabWidget::TabShape **tabShape** )

        **See also** **setTabPosition** ().
        """
        ...

    def setDocumentMode(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#documentMode-prop

        **documentMode : bool**

        This property holds whether the tab bar for tabbed dockwidgets is set to
        document mode.

        The default is false.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool
        **enabled** )

        **See also** **QTabBar::documentMode** .
        """
        ...

    def documentMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#documentMode-prop

        **documentMode : bool**

        This property holds whether the tab bar for tabbed dockwidgets is set to
        document mode.

        The default is false.

        **Access functions:**

        bool **documentMode** () const
        void **setDocumentMode** (bool
        **enabled** )

        **See also** **QTabBar::documentMode** .
        """
        ...

    def restoreDockWidget(self, dockwidget: QDockWidget) -> bool:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#restoreDockWidget

        **bool QMainWindow::restoreDockWidget(QDockWidget * dockwidget )**

        Restores the state of **dockwidget** if it is created after the call to
        **restoreState** (). Returns `true` if the state was restored; otherwise
        returns `false`.

        **See also** **restoreState** () and **saveState** ().
        """
        ...

    def unifiedTitleAndToolBarOnMac(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#unifiedTitleAndToolBarOnMac-prop

        **[since 5.2] unifiedTitleAndToolBarOnMac : bool**

        This property holds whether the window uses the unified title and
        toolbar look on macOS

        Note that the Qt 5 implementation has several limitations compared to Qt
        4:

        * Use in windows with OpenGL content is not supported. This includes
        QOpenGLWidget.
          * Using dockable or movable toolbars may result in
        painting errors and is not recommended

        This property was introduced in Qt 5.2.

        **Access functions:**

        bool **unifiedTitleAndToolBarOnMac** () const
        void
        **setUnifiedTitleAndToolBarOnMac** (bool **set** )

        **Member Function Documentation**
        """
        ...

    def setUnifiedTitleAndToolBarOnMac(self, set: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#unifiedTitleAndToolBarOnMac-prop

        **[since 5.2] unifiedTitleAndToolBarOnMac : bool**

        This property holds whether the window uses the unified title and
        toolbar look on macOS

        Note that the Qt 5 implementation has several limitations compared to Qt
        4:

        * Use in windows with OpenGL content is not supported. This includes
        QOpenGLWidget.
          * Using dockable or movable toolbars may result in
        painting errors and is not recommended

        This property was introduced in Qt 5.2.

        **Access functions:**

        bool **unifiedTitleAndToolBarOnMac** () const
        void
        **setUnifiedTitleAndToolBarOnMac** (bool **set** )

        **Member Function Documentation**
        """
        ...

    def toolBarBreak(self, toolbar: "QToolBar") -> bool:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#toolBarBreak

        **bool QMainWindow::toolBarBreak(QToolBar * toolbar ) const**

        Returns whether there is a toolbar break before the **toolbar**.

        **See also** **addToolBarBreak** () and **insertToolBarBreak** ().
        """
        ...

    def removeToolBarBreak(self, before: "QToolBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#removeToolBarBreak

        **void QMainWindow::removeToolBarBreak(QToolBar * before )**

        Removes a toolbar break previously inserted before the toolbar specified
        by **before**.
        """
        ...

    def dockOptions(self) -> "QMainWindow.DockOption":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#dockOptions-prop

        **dockOptions : DockOptions**

        This property holds the docking behavior of **QMainWindow**

        The default value is **AnimatedDocks**  | **AllowTabbedDocks** .

        **Access functions:**

        QMainWindow::DockOptions **dockOptions** () const
        void
        **setDockOptions** (QMainWindow::DockOptions **options** )
        """
        ...

    def setDockOptions(self, options: "QMainWindow.DockOption") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#dockOptions-prop

        **dockOptions : DockOptions**

        This property holds the docking behavior of **QMainWindow**

        The default value is **AnimatedDocks**  | **AllowTabbedDocks** .

        **Access functions:**

        QMainWindow::DockOptions **dockOptions** () const
        void
        **setDockOptions** (QMainWindow::DockOptions **options** )
        """
        ...

    def tabifyDockWidget(self, first: QDockWidget, second: QDockWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#tabifyDockWidget

        **void QMainWindow::tabifyDockWidget(QDockWidget * first , QDockWidget *
        second )**

        Moves **second** dock widget on top of **first** dock widget, creating a
        tabbed docked area in the main window.

        **See also** **tabifiedDockWidgets** ().
        """
        ...

    def setMenuWidget(self, menubar: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#setMenuWidget

        **void QMainWindow::setMenuWidget(QWidget * menuBar )**

        Sets the menu bar for the main window to **menuBar**.

        **QMainWindow**  takes ownership of the **menuBar** pointer and deletes
        it at the appropriate time.

        **See also** **menuWidget** ().
        """
        ...

    def menuWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#menuWidget

        **QWidget *QMainWindow::menuWidget() const**

        Returns the menu bar for the main window. This function returns null if
        a menu bar hasn't been constructed yet.

        **See also** **setMenuWidget** ().
        """
        ...

    def isSeparator(self, pos: QtCore.QPoint) -> bool:
        ...

    def isDockNestingEnabled(self) -> bool:
        ...

    def isAnimated(self) -> bool:
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#event

        **[override virtual protected] bool QMainWindow::event(QEvent * event
        )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def contextMenuEvent(self, event: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#contextMenuEvent

        **[override virtual protected] void
        QMainWindow::contextMenuEvent(QContextMenuEvent * event )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).
        """
        ...

    def setDockNestingEnabled(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#dockNestingEnabled-prop

        **dockNestingEnabled : bool**

        This property holds whether docks can be nested

        If this property is `false`, dock areas can only contain a single row
        (horizontal or vertical) of dock widgets. If this property is `true`,
        the area occupied by a dock widget can be split in either direction to
        contain more dock widgets.

        Dock nesting is only necessary in applications that contain a lot of
        dock widgets. It gives the user greater freedom in organizing their main
        window. However, dock nesting leads to more complex (and less intuitive)
        behavior when a dock widget is dragged over the main window, since there
        are more ways in which a dropped dock widget may be placed in the dock
        area.

        Setting this property is identical to setting the **AllowNestedDocks**
        option using **setDockOptions** ().

        **Access functions:**

        bool **isDockNestingEnabled** () const
        void **setDockNestingEnabled**
        (bool **enabled** )
        """
        ...

    def setAnimated(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#animated-prop

        **animated : bool**

        This property holds whether manipulating dock widgets and tool bars is
        animated

        When a dock widget or tool bar is dragged over the main window, the main
        window adjusts its contents to indicate where the dock widget or tool
        bar will be docked if it is dropped. Setting this property causes
        **QMainWindow**  to move its contents in a smooth animation. Clearing
        this property causes the contents to snap into their new positions.

        By default, this property is set. It may be cleared if the main window
        contains widgets which are slow at resizing or repainting themselves.

        Setting this property is identical to setting the **AnimatedDocks**
        option using **setDockOptions** ().

        **Access functions:**

        bool **isAnimated** () const
        void **setAnimated** (bool **enabled** )
        """
        ...

    def createPopupMenu(self) -> "QMenu":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#createPopupMenu

        **[virtual] QMenu *QMainWindow::createPopupMenu()**

        Returns a popup menu containing checkable entries for the toolbars and
        dock widgets present in the main window. If there are no toolbars and
        dock widgets present, this function returns `nullptr`.

        By default, this function is called by the main window when the user
        activates a context menu, typically by right-clicking on a toolbar or a
        dock widget.

        If you want to create a custom popup menu, reimplement this function and
        return a newly-created popup menu. Ownership of the popup menu is
        transferred to the caller.

        **See also** **addDockWidget** (), **addToolBar** (), and **menuBar**
        ().
        """
        ...

    def restoreState(self, state: QtCore.QByteArray, version: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#restoreState

        **bool QMainWindow::restoreState(const QByteArray & state , int version
        = 0)**

        Restores the **state** of this mainwindow's toolbars and dockwidgets.
        Also restores the corner settings too. The **version** number is
        compared with that stored in **state**. If they do not match, the
        mainwindow's state is left unchanged, and this function returns `false`;
        otherwise, the state is restored, and this function returns `true`.

        To restore geometry saved using **QSettings** , you can use code like
        this:

        void MainWindow::readSettings()
            {
                **QSettings**
        settings("MyCompany", "MyApp");
        restoreGeometry(settings.value("myWidget/geometry").toByteArray());
        restoreState(settings.value("myWidget/windowState").toByteArray());
        }

        **See also** **saveState** (), **QWidget::saveGeometry** (),
        **QWidget::restoreGeometry** (), and **restoreDockWidget** ().
        """
        ...

    def saveState(self, version: int = ...) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#saveState

        **QByteArray QMainWindow::saveState(int version = 0) const**

        Saves the current state of this mainwindow's toolbars and dockwidgets.
        This includes the corner settings which can be set with **setCorner**
        (). The **version** number is stored as part of the data.

        The **objectName**  property is used to identify each **QToolBar**  and
        **QDockWidget** . You should make sure that this property is unique for
        each **QToolBar**  and **QDockWidget**  you add to the **QMainWindow**

        To restore the saved state, pass the return value and **version** number
        to **restoreState** ().

        To save the geometry when the window closes, you can implement a close
        event like this:

        void MyMainWindow::closeEvent(**QCloseEvent**  *event)
            {
        **QSettings**  settings("MyCompany", "MyApp");
        settings.setValue("geometry", saveGeometry());
        settings.setValue("windowState", saveState());
                **QMainWindow**
        ::closeEvent(event);
            }

        **See also** **restoreState** (), **QWidget::saveGeometry** (), and
        **QWidget::restoreGeometry** ().
        """
        ...

    def dockWidgetArea(self, dockwidget: QDockWidget) -> QtCore.Qt.DockWidgetArea:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#dockWidgetArea

        **Qt::DockWidgetArea QMainWindow::dockWidgetArea(QDockWidget *
        dockwidget ) const**

        Returns the **Qt::DockWidgetArea**  for **dockwidget**. If
        **dockwidget** has not been added to the main window, this function
        returns `Qt::NoDockWidgetArea`.

        **See also** **addDockWidget** (), **splitDockWidget** (), and
        **Qt::DockWidgetArea** .
        """
        ...

    def removeDockWidget(self, dockwidget: QDockWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#removeDockWidget

        **void QMainWindow::removeDockWidget(QDockWidget * dockwidget )**

        Removes the **dockwidget** from the main window layout and hides it.
        Note that the **dockwidget** is **not** deleted.
        """
        ...

    def splitDockWidget(
        self,
        after: QDockWidget,
        dockwidget: QDockWidget,
        orientation: QtCore.Qt.Orientation,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#splitDockWidget

        **void QMainWindow::splitDockWidget(QDockWidget * first , QDockWidget *
        second , Qt::Orientation orientation )**

        Splits the space covered by the **first** dock widget into two parts,
        moves the **first** dock widget into the first part, and moves the
        **second** dock widget into the second part.

        The **orientation** specifies how the space is divided: A
        **Qt::Horizontal**  split places the second dock widget to the right of
        the first; a **Qt::Vertical**  split places the second dock widget below
        the first.

        **Note** : if **first** is currently in a tabbed docked area, **second**
        will be added as a new tab, not as a neighbor of **first**. This is
        because a single tab can contain only one dock widget.

        **Note** : The **Qt::LayoutDirection**  influences the order of the dock
        widgets in the two parts of the divided area. When right-to-left layout
        direction is enabled, the placing of the dock widgets will be reversed.

        **See also** **tabifyDockWidget** (), **addDockWidget** (), and
        **removeDockWidget** ().
        """
        ...

    @typing.overload
    def addDockWidget(
        self, area: QtCore.Qt.DockWidgetArea, dockwidget: QDockWidget
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#addDockWidget

        **void QMainWindow::addDockWidget(Qt::DockWidgetArea area , QDockWidget
        * dockwidget )**

        Adds the given **dockwidget** to the specified **area**.
        """
        ...

    @typing.overload
    def addDockWidget(
        self,
        area: QtCore.Qt.DockWidgetArea,
        dockwidget: QDockWidget,
        orientation: QtCore.Qt.Orientation,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#addDockWidget-1

        **void QMainWindow::addDockWidget(Qt::DockWidgetArea area , QDockWidget
        * dockwidget , Qt::Orientation orientation )**

        Adds **dockwidget** into the given **area** in the direction specified
        by the **orientation**.
        """
        ...

    def toolBarArea(self, toolbar: "QToolBar") -> QtCore.Qt.ToolBarArea:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#toolBarArea

        **Qt::ToolBarArea QMainWindow::toolBarArea(const QToolBar * toolbar )
        const**

        Returns the **Qt::ToolBarArea**  for **toolbar**. If **toolbar** has not
        been added to the main window, this function returns
        `Qt::NoToolBarArea`.

        **See also** **addToolBar** (), **addToolBarBreak** (), and
        **Qt::ToolBarArea** .
        """
        ...

    def removeToolBar(self, toolbar: "QToolBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#removeToolBar

        **void QMainWindow::removeToolBar(QToolBar * toolbar )**

        Removes the **toolbar** from the main window layout and hides it. Note
        that the **toolbar** is **not** deleted.
        """
        ...

    def insertToolBar(self, before: "QToolBar", toolbar: "QToolBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#insertToolBar

        **void QMainWindow::insertToolBar(QToolBar * before , QToolBar * toolbar
        )**

        Inserts the **toolbar** into the area occupied by the **before** toolbar
        so that it appears before it. For example, in normal left-to-right
        layout operation, this means that **toolbar** will appear to the left of
        the toolbar specified by **before** in a horizontal toolbar area.

        **See also** **insertToolBarBreak** (), **addToolBar** (), and
        **addToolBarBreak** ().
        """
        ...

    @typing.overload
    def addToolBar(self, area: QtCore.Qt.ToolBarArea, toolbar: "QToolBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#addToolBar

        **void QMainWindow::addToolBar(Qt::ToolBarArea area , QToolBar * toolbar
        )**

        Adds the **toolbar** into the specified **area** in this main window.
        The **toolbar** is placed at the end of the current tool bar block (i.e.
        line). If the main window already manages **toolbar** then it will only
        move the toolbar to **area**.

        **See also** **insertToolBar** (), **addToolBarBreak** (), and
        **insertToolBarBreak** ().
        """
        ...

    @typing.overload
    def addToolBar(self, toolbar: "QToolBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#addToolBar-1

        **void QMainWindow::addToolBar(QToolBar * toolbar )**

        This is an overloaded function.

        Equivalent of calling addToolBar(**Qt::TopToolBarArea** , **toolbar** )
        """
        ...

    @typing.overload
    def addToolBar(self, title: str) -> "QToolBar":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#addToolBar-2

        **QToolBar *QMainWindow::addToolBar(const QString & title )**

        This is an overloaded function.

        Creates a **QToolBar**  object, setting its window title to **title** ,
        and inserts it into the top toolbar area.

        **See also** **setWindowTitle** ().
        """
        ...

    def insertToolBarBreak(self, before: "QToolBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#insertToolBarBreak

        **void QMainWindow::insertToolBarBreak(QToolBar * before )**

        Inserts a toolbar break before the toolbar specified by **before**.
        """
        ...

    def addToolBarBreak(self, area: QtCore.Qt.ToolBarArea = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#addToolBarBreak

        **void QMainWindow::addToolBarBreak(Qt::ToolBarArea area =
        Qt::TopToolBarArea)**

        Adds a toolbar break to the given **area** after all the other objects
        that are present.
        """
        ...

    def corner(self, corner: QtCore.Qt.Corner) -> QtCore.Qt.DockWidgetArea:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#corner

        **Qt::DockWidgetArea QMainWindow::corner(Qt::Corner corner ) const**

        Returns the dock widget area that occupies the specified **corner**.

        **See also** **setCorner** ().
        """
        ...

    def setCorner(
        self, corner: QtCore.Qt.Corner, area: QtCore.Qt.DockWidgetArea
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#setCorner

        **void QMainWindow::setCorner(Qt::Corner corner , Qt::DockWidgetArea
        area )**

        Sets the given dock widget **area** to occupy the specified **corner**.

        **See also** **corner** ().
        """
        ...

    def setCentralWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#setCentralWidget

        **void QMainWindow::setCentralWidget(QWidget * widget )**

        Sets the given **widget** to be the main window's central widget.

        Note: **QMainWindow**  takes ownership of the **widget** pointer and
        deletes it at the appropriate time.

        **See also** **centralWidget** ().
        """
        ...

    def centralWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#centralWidget

        **QWidget *QMainWindow::centralWidget() const**

        Returns the central widget for the main window. This function returns
        zero if the central widget has not been set.

        **See also** **setCentralWidget** ().
        """
        ...

    def setStatusBar(self, statusbar: "QStatusBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#setStatusBar

        **void QMainWindow::setStatusBar(QStatusBar * statusbar )**

        Sets the status bar for the main window to **statusbar**.

        Setting the status bar to `nullptr` will remove it from the main window.
        Note that **QMainWindow**  takes ownership of the **statusbar** pointer
        and deletes it at the appropriate time.

        **See also** **statusBar** ().
        """
        ...

    def statusBar(self) -> "QStatusBar":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#statusBar

        **QStatusBar *QMainWindow::statusBar() const**

        Returns the status bar for the main window. This function creates and
        returns an empty status bar if the status bar does not exist.

        **See also** **setStatusBar** ().
        """
        ...

    def setMenuBar(self, menubar: "QMenuBar") -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#setMenuBar

        **void QMainWindow::setMenuBar(QMenuBar * menuBar )**

        Sets the menu bar for the main window to **menuBar**.

        Note: **QMainWindow**  takes ownership of the **menuBar** pointer and
        deletes it at the appropriate time.

        **See also** **menuBar** ().
        """
        ...

    def menuBar(self) -> "QMenuBar":
        """
        https://doc.qt.io/qt-6/qmainwindow.html#menuBar

        **QMenuBar *QMainWindow::menuBar() const**

        Returns the menu bar for the main window. This function creates and
        returns an empty menu bar if the menu bar does not exist.

        If you want all windows in a Mac application to share one menu bar,
        don't use this function to create it, because the menu bar created here
        will have this **QMainWindow**  as its parent. Instead, you must create
        a menu bar that does not have a parent, which you can then share among
        all the Mac windows. Create a parent-less menu bar this way:

        **QMenuBar**  *menuBar = new **QMenuBar** (nullptr);

        **See also** **setMenuBar** ().
        """
        ...

    def setToolButtonStyle(self, toolButtonStyle: QtCore.Qt.ToolButtonStyle) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#toolButtonStyle-prop

        **toolButtonStyle : Qt::ToolButtonStyle**

        style of toolbar buttons in this mainwindow.

        To have the style of toolbuttons follow the system settings, set this
        property to **Qt::ToolButtonFollowStyle** . On Unix, the user settings
        from the desktop environment will be used. On other platforms,
        **Qt::ToolButtonFollowStyle**  means icon only.

        The default is **Qt::ToolButtonIconOnly** .

        **Access functions:**

        Qt::ToolButtonStyle **toolButtonStyle** () const
        void
        **setToolButtonStyle** (Qt::ToolButtonStyle **toolButtonStyle** )
        """
        ...

    def toolButtonStyle(self) -> QtCore.Qt.ToolButtonStyle:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#toolButtonStyle-prop

        **toolButtonStyle : Qt::ToolButtonStyle**

        style of toolbar buttons in this mainwindow.

        To have the style of toolbuttons follow the system settings, set this
        property to **Qt::ToolButtonFollowStyle** . On Unix, the user settings
        from the desktop environment will be used. On other platforms,
        **Qt::ToolButtonFollowStyle**  means icon only.

        The default is **Qt::ToolButtonIconOnly** .

        **Access functions:**

        Qt::ToolButtonStyle **toolButtonStyle** () const
        void
        **setToolButtonStyle** (Qt::ToolButtonStyle **toolButtonStyle** )
        """
        ...

    def setIconSize(self, iconSize: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#iconSize-prop

        **iconSize : QSize**

        size of toolbar icons in this mainwindow.

        The default is the default tool bar icon size of the GUI style. Note
        that the icons used must be at least of this size as the icons are only
        scaled down.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **iconSize** )
        """
        ...

    def iconSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#iconSize-prop

        **iconSize : QSize**

        size of toolbar icons in this mainwindow.

        The default is the default tool bar icon size of the GUI style. Note
        that the icons used must be at least of this size as the icons are only
        scaled down.

        **Access functions:**

        QSize **iconSize** () const
        void **setIconSize** (const QSize &
        **iconSize** )
        """
        ...

    @property
    def iconSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#iconSizeChanged

        **[signal] void QMainWindow::iconSizeChanged(const QSize & iconSize )**

        This signal is emitted when the size of the icons used in the window is
        changed. The new icon size is passed in **iconSize**.

        You can connect this signal to other components to help maintain a
        consistent appearance for your application.

        **See also** **setIconSize** ().
        """
        ...

    @property
    def tabifiedDockWidgetActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#tabifiedDockWidgetActivated

        **[signal, since 5.8] void
        QMainWindow::tabifiedDockWidgetActivated(QDockWidget * dockWidget )**

        This signal is emitted when the tabified dock widget is activated by
        selecting the tab. The activated dock widget is passed in
        **dockWidget**.

        This function was introduced in Qt 5.8.

        **See also** **tabifyDockWidget** () and **tabifiedDockWidgets** ().
        """
        ...

    @property
    def toolButtonStyleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmainwindow.html#toolButtonStyleChanged

        **[signal] void QMainWindow::toolButtonStyleChanged(Qt::ToolButtonStyle
        toolButtonStyle )**

        This signal is emitted when the style used for tool buttons in the
        window is changed. The new style is passed in **toolButtonStyle**.

        You can connect this signal to other components to help maintain a
        consistent appearance for your application.

        **See also** **setToolButtonStyle** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QNetworkProxyQuery(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnetworkproxyquery.html

    **Detailed Description**

    QNetworkProxyQuery holds the details of a socket being created or request
    being made. It is used by **QNetworkProxy**  and **QNetworkProxyFactory**
    to allow applications to have a more fine-grained control over which proxy
    servers are used, depending on the details of the query. This allows an
    application to apply different settings, according to the protocol or
    destination hostname, for instance.

    QNetworkProxyQuery supports the following criteria for selecting the proxy:

    * the type of query
      * the local port number to use
      * the destination
    host name
      * the destination port number
      * the protocol name, such as
    "http" or "ftp"
      * the URL being requested

    The destination host name is the host in the connection in the case of
    outgoing connection sockets. It is the `hostName` parameter passed to
    **QTcpSocket::connectToHost** () or the host component of a URL requested
    with **QNetworkRequest** .

    The destination port number is the requested port to connect to in the case
    of outgoing sockets, while the local port number is the port the socket
    wishes to use locally before attempting the external connection. In most
    cases, the local port number is used by listening sockets only
    (**QTcpSocket** ) or by datagram sockets (**QUdpSocket** ).

    The protocol name is an arbitrary string that indicates the type of
    connection being attempted. For example, it can match the scheme of a URL,
    like "http", "https" and "ftp". In most cases, the proxy selection will not
    change depending on the protocol, but this information is provided in case a
    better choice can be made, like choosing an caching HTTP proxy for HTTP-
    based connections, but a more powerful SOCKSv5 proxy for all others.

    Some of the criteria may not make sense in all of the types of query. The
    following table lists the criteria that are most commonly used, according to
    the type of query.

    Query typeDescription
    **TcpSocket** Normal sockets requesting a connection
    to a remote server, like **QTcpSocket** . The peer hostname and peer port
    match the values passed to **QTcpSocket::connectToHost** (). The local port
    is usually -1, indicating the socket has no preference in which port should
    be used. The URL component is not used.
    **UdpSocket** Datagram-based
    sockets, which can both send and receive. The local port, remote host or
    remote port fields can all be used or be left unused, depending on the
    characteristics of the socket. The URL component is not used.
    **SctpSocket** Message-oriented sockets requesting a connection to a remote
    server. The peer hostname and peer port match the values passed to
    **QSctpSocket::connectToHost** (). The local port is usually -1, indicating
    the socket has no preference in which port should be used. The URL component
    is not used.
    **TcpServer** Passive server sockets that listen on a port
    and await incoming connections from the network. Normally, only the local
    port is used, but the remote address could be used in specific
    circumstances, for example to indicate which remote host a connection is
    expected from. The URL component is not used.
    **UrlRequest** A more high-
    level request, such as those coming from **QNetworkAccessManager** . These
    requests will inevitably use an outgoing TCP socket, but the this query type
    is provided to indicate that more detailed information is present in the URL
    component. For ease of implementation, the URL's host and port are set as
    the destination address.
    **SctpServer** Passive server sockets that listen
    on an SCTP port and await incoming connections from the network. Normally,
    only the local port is used, but the remote address could be used in
    specific circumstances, for example to indicate which remote host a
    connection is expected from. The URL component is not used.

    It should be noted that any of the criteria may be missing or unknown (an
    empty **QString**  for the hostname or protocol name, -1 for the port
    numbers). If that happens, the functions executing the query should make
    their best guess or apply some implementation-defined default values.

    **See also** **QNetworkProxy** , **QNetworkProxyFactory** ,
    **QNetworkAccessManager** , and **QAbstractSocket::setProxy** ().
    """

    class QueryType(enum.Enum):
        TcpSocket: QNetworkProxyQuery = ...
        UdpSocket: QNetworkProxyQuery = ...
        TcpServer: QNetworkProxyQuery = ...
        UrlRequest: QNetworkProxyQuery = ...
        SctpSocket: QNetworkProxyQuery = ...
        SctpServer: QNetworkProxyQuery = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#QNetworkProxyQuery

        **QNetworkProxyQuery::QNetworkProxyQuery()**

        Constructs a default QNetworkProxyQuery object. By default, the query
        type will be **QNetworkProxyQuery::TcpSocket** .
        """
        ...

    @typing.overload
    def __init__(
        self, requestUrl: QtCore.QUrl, type: "QNetworkProxyQuery.QueryType" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#QNetworkProxyQuery-1

        **QNetworkProxyQuery::QNetworkProxyQuery(const QUrl & requestUrl ,
        QNetworkProxyQuery::QueryType queryType = UrlRequest)**

        Constructs a QNetworkProxyQuery with the URL **requestUrl** and sets the
        query type to **queryType**.

        **See also** **protocolTag** (), **peerHostName** (), and **peerPort**
        ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        hostname: str,
        port: int,
        protocolTag: str = ...,
        type: "QNetworkProxyQuery.QueryType" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#QNetworkProxyQuery-2

        **QNetworkProxyQuery::QNetworkProxyQuery(const QString & hostname , int
        port , const QString & protocolTag = QString(),
        QNetworkProxyQuery::QueryType queryType = TcpSocket)**

        Constructs a QNetworkProxyQuery of type **queryType** and sets the
        protocol tag to be **protocolTag**. This constructor is suitable for
        **QNetworkProxyQuery::TcpSocket**  queries, because it sets the peer
        hostname to **hostname** and the peer's port number to **port**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        bindPort: int,
        protocolTag: str = ...,
        type: "QNetworkProxyQuery.QueryType" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#QNetworkProxyQuery-3

        **QNetworkProxyQuery::QNetworkProxyQuery(quint16 bindPort , const
        QString & protocolTag = QString(), QNetworkProxyQuery::QueryType
        queryType = TcpServer)**

        Constructs a QNetworkProxyQuery of type **queryType** and sets the
        protocol tag to be **protocolTag**. This constructor is suitable for
        **QNetworkProxyQuery::TcpSocket**  queries because it sets the local
        port number to **bindPort**.

        Note that **bindPort** is of type quint16 to indicate the exact port
        number that is requested. The value of -1 (unknown) is not allowed in
        this context.

        **See also** **localPort** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QNetworkProxyQuery") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#QNetworkProxyQuery-4

        **QNetworkProxyQuery::QNetworkProxyQuery(const QNetworkProxyQuery &
        other )**

        Constructs a QNetworkProxyQuery object that is a copy of **other**.
        """
        ...

    def swap(self, other: "QNetworkProxyQuery") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#swap

        **[since 5.0] void QNetworkProxyQuery::swap(QNetworkProxyQuery & other
        )**

        Swaps this network proxy query instance with **other**. This function is
        very fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def setUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#setUrl

        **void QNetworkProxyQuery::setUrl(const QUrl & url )**

        Sets the URL component of this **QNetworkProxyQuery**  object to be
        **url**. Setting the URL will also set the protocol tag, the remote host
        name and port number. This is done so as to facilitate the
        implementation of the code that determines the proxy server to be used.

        **See also** **url** (), **peerHostName** (), and **peerPort** ().
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#url

        **QUrl QNetworkProxyQuery::url() const**

        Returns the URL component of this **QNetworkProxyQuery**  object in case
        of a query of type **QNetworkProxyQuery::UrlRequest** .

        **See also** **setUrl** ().
        """
        ...

    def setProtocolTag(self, protocolTag: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#setProtocolTag

        **void QNetworkProxyQuery::setProtocolTag(const QString & protocolTag
        )**

        Sets the protocol tag for this **QNetworkProxyQuery**  object to be
        **protocolTag**.

        The protocol tag is an arbitrary string that indicates which protocol is
        being talked over the socket, such as "http", "xmpp", "telnet", etc. The
        protocol tag is used by the backend to return a request that is more
        specific to the protocol in question: for example, a HTTP connection
        could be use a caching HTTP proxy server, while all other connections
        use a more powerful SOCKSv5 proxy server.

        **See also** **protocolTag** ().
        """
        ...

    def protocolTag(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#protocolTag

        **QString QNetworkProxyQuery::protocolTag() const**

        Returns the protocol tag for this **QNetworkProxyQuery**  object, or an
        empty **QString**  in case the protocol tag is unknown.

        In the case of queries of type **QNetworkProxyQuery::UrlRequest** , this
        function returns the value of the scheme component of the URL.

        **See also** **setProtocolTag** () and **url** ().
        """
        ...

    def setLocalPort(self, port: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#setLocalPort

        **void QNetworkProxyQuery::setLocalPort(int port )**

        Sets the port number that the socket wishes to use locally to accept
        incoming packets from remote servers to **port**. The local port is most
        often used with the **QNetworkProxyQuery::TcpServer**  and
        **QNetworkProxyQuery::UdpSocket**  query types.

        Valid values are 0 to 65535 (with 0 indicating that any port number will
        be acceptable) or -1, which means the local port number is unknown or
        not applicable.

        In some circumstances, for special protocols, it's the local port number
        can also be used with a query of type **QNetworkProxyQuery::TcpSocket**
        . When that happens, the socket is indicating it wishes to use the port
        number **port** when connecting to a remote host.

        **See also** **localPort** (), **setPeerPort** (), and
        **setPeerHostName** ().
        """
        ...

    def localPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#localPort

        **int QNetworkProxyQuery::localPort() const**

        Returns the port number of the socket that will accept incoming packets
        from remote servers or -1 if the port is not known.

        **See also** **peerPort** (), **peerHostName** (), and **setLocalPort**
        ().
        """
        ...

    def setPeerHostName(self, hostname: str) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#setPeerHostName

        **void QNetworkProxyQuery::setPeerHostName(const QString & hostname )**

        Sets the hostname of the outgoing connection being requested to
        **hostname**. An empty hostname can be used to indicate that the remote
        host is unknown.

        The peer host name can also be used to indicate the expected source
        address of an incoming connection in the case of
        **QNetworkProxyQuery::UdpSocket**  or **QNetworkProxyQuery::TcpServer**
        query types.

        **See also** **peerHostName** (), **setPeerPort** (), and
        **setLocalPort** ().
        """
        ...

    def peerHostName(self) -> str:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#peerHostName

        **QString QNetworkProxyQuery::peerHostName() const**

        Returns the host name or IP address being of the outgoing connection
        being requested, or an empty string if the remote hostname is not known.

        If the query type is **QNetworkProxyQuery::UrlRequest** , this function
        returns the host component of the URL being requested.

        **See also** **peerPort** (), **localPort** (), and **setPeerHostName**
        ().
        """
        ...

    def setPeerPort(self, port: int) -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#setPeerPort

        **void QNetworkProxyQuery::setPeerPort(int port )**

        Sets the requested port number for the outgoing connection to be
        **port**. Valid values are 1 to 65535, or -1 to indicate that the remote
        port number is unknown.

        The peer port number can also be used to indicate the expected port
        number of an incoming connection in the case of
        **QNetworkProxyQuery::UdpSocket**  or **QNetworkProxyQuery::TcpServer**
        query types.

        **See also** **peerPort** (), **setPeerHostName** (), and
        **setLocalPort** ().
        """
        ...

    def peerPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#peerPort

        **int QNetworkProxyQuery::peerPort() const**

        Returns the port number for the outgoing request or -1 if the port
        number is not known.

        If the query type is **QNetworkProxyQuery::UrlRequest** , this function
        returns the port number of the URL being requested. In general,
        frameworks will fill in the port number from their default values.

        **See also** **peerHostName** (), **localPort** (), and **setPeerPort**
        ().
        """
        ...

    def setQueryType(self, type: "QNetworkProxyQuery.QueryType") -> None:
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#setQueryType

        **void QNetworkProxyQuery::setQueryType(QNetworkProxyQuery::QueryType
        type )**

        Sets the query type of this object to be **type**.

        **See also** **queryType** ().
        """
        ...

    def queryType(self) -> "QNetworkProxyQuery.QueryType":
        """
        https://doc.qt.io/qt-6/qnetworkproxyquery.html#queryType

        **QNetworkProxyQuery::QueryType QNetworkProxyQuery::queryType() const**

        Returns the query type.

        **See also** **setQueryType** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QRgba64(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qrgba64.html

    **Detailed Description**

    QRgba64 is a 64-bit data-structure containing four 16-bit color channels:
    Red, green, blue and alpha.

    QRgba64 can be used as a replacement for **QRgb**  when higher precision is
    needed. In particular a premultiplied QRgba64 can operate on unpremultiplied
    **QRgb**  without loss of precision except for alpha 0.

    **See also** **QRgb**  and **QColor** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QRgba64") -> None:
        ...

    def __int__(self) -> int:
        ...

    def unpremultiplied(self) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qrgba64.html#unpremultiplied

        **QRgba64 QRgba64::unpremultiplied() const**

        Returns the color with the alpha unpremultiplied.

        **See also** **premultiplied** ().
        """
        ...

    def premultiplied(self) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qrgba64.html#premultiplied

        **QRgba64 QRgba64::premultiplied() const**

        Returns the color with the alpha premultiplied.

        **See also** **unpremultiplied** ().
        """
        ...

    def toRgb16(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#toRgb16

        **ushort QRgba64::toRgb16() const**

        Returns the color as a 16-bit RGB value.

        **See also** **toArgb32** ().
        """
        ...

    def toArgb32(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#toArgb32

        **uint QRgba64::toArgb32() const**

        Returns the color as a 32-bit ARGB value.

        **See also** **fromArgb32** ().
        """
        ...

    def alpha8(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#alpha8

        **quint8 QRgba64::alpha8() const**

        Returns the alpha channel as an 8-bit.
        """
        ...

    def blue8(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#blue8

        **quint8 QRgba64::blue8() const**

        Returns the blue color component as an 8-bit.
        """
        ...

    def green8(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#green8

        **quint8 QRgba64::green8() const**

        Returns the green color component as an 8-bit.
        """
        ...

    def red8(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#red8

        **quint8 QRgba64::red8() const**

        Returns the red color component as an 8-bit.
        """
        ...

    def setAlpha(self, _alpha: int) -> None:
        """
        https://doc.qt.io/qt-6/qrgba64.html#setAlpha

        **void QRgba64::setAlpha(quint16 alpha )**

        Sets the alpha of this color to **alpha**.

        **See also** **alpha** ().
        """
        ...

    def setBlue(self, _blue: int) -> None:
        """
        https://doc.qt.io/qt-6/qrgba64.html#setBlue

        **void QRgba64::setBlue(quint16 blue )**

        Sets the blue color component of this color to **blue**.

        **See also** **blue** ().
        """
        ...

    def setGreen(self, _green: int) -> None:
        """
        https://doc.qt.io/qt-6/qrgba64.html#setGreen

        **void QRgba64::setGreen(quint16 green )**

        Sets the green color component of this color to **green**.

        **See also** **green** ().
        """
        ...

    def setRed(self, _red: int) -> None:
        """
        https://doc.qt.io/qt-6/qrgba64.html#setRed

        **void QRgba64::setRed(quint16 red )**

        Sets the red color component of this color to **red**.

        **See also** **red** ().
        """
        ...

    def alpha(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#alpha

        **quint16 QRgba64::alpha() const**

        Returns the 16-bit alpha channel.

        **See also** **setAlpha** ().
        """
        ...

    def blue(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#blue

        **quint16 QRgba64::blue() const**

        Returns the 16-bit blue color component.

        **See also** **setBlue** ().
        """
        ...

    def green(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#green

        **quint16 QRgba64::green() const**

        Returns the 16-bit green color component.

        **See also** **setGreen** ().
        """
        ...

    def red(self) -> int:
        """
        https://doc.qt.io/qt-6/qrgba64.html#red

        **quint16 QRgba64::red() const**

        Returns the 16-bit red color component.

        **See also** **setRed** ().
        """
        ...

    def isTransparent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrgba64.html#isTransparent

        **bool QRgba64::isTransparent() const**

        Returns whether the color is transparent.

        **See also** **isOpaque** () and **alpha** ().
        """
        ...

    def isOpaque(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrgba64.html#isOpaque

        **bool QRgba64::isOpaque() const**

        Returns whether the color is fully opaque.

        **See also** **isTransparent** () and **alpha** ().
        """
        ...

    @staticmethod
    def fromArgb32(rgb: int) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qrgba64.html#fromArgb32

        **[static] QRgba64 QRgba64::fromArgb32(uint rgb )**

        Constructs a **QRgba64**  value from the 32bit ARGB value **rgb**.

        **See also** **fromRgba** ().
        """
        ...

    @staticmethod
    def fromRgba(red: int, green: int, blue: int, alpha: int) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qrgba64.html#fromRgba

        **[static] QRgba64 QRgba64::fromRgba(quint8 red , quint8 green , quint8
        blue , quint8 alpha )**

        Constructs a **QRgba64**  value from the four 8-bit color channels
        **red** , **green** , **blue** and **alpha**.

        **See also** **fromArgb32** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromRgba64(c: int) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qrgba64.html#fromRgba64

        **[static] QRgba64 QRgba64::fromRgba64(quint64 c )**

        Returns **c** as a **QRgba64**  struct.

        **See also** **fromArgb32** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromRgba64(red: int, green: int, blue: int, alpha: int) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qrgba64.html#fromRgba64-1

        **[static] QRgba64 QRgba64::fromRgba64(quint16 r , quint16 g , quint16 b
        , quint16 a )**

        Returns the **QRgba64**  quadruplet ( **r** , **g** , **b** , **a** ).

        **See also** **fromRgba** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGOpaqueTextureMaterial(QSGMaterial):
    """
    https://doc.qt.io/qt-6/qsgopaquetexturematerial.html

    **Detailed Description**

    **Warning:** This utility class is only functional when running with the
    default backend of the Qt Quick scenegraph.

    The opaque textured material will fill every pixel in a geometry with the
    supplied texture. The material does not respect the opacity of the
    **QSGMaterialShader::RenderState** , so opacity nodes in the parent chain of
    nodes using this material, have no effect.

    The geometry to be rendered with an opaque texture material requires
    vertices in attribute location 0 and texture coordinates in attribute
    location 1. The texture coordinate is a 2-dimensional floating-point tuple.
    The **QSGGeometry::defaultAttributes_TexturedPoint2D**  returns an attribute
    set compatible with this material.

    The texture to be rendered can be set using **setTexture** (). How the
    texture should be rendered can be specified using **setMipmapFiltering** (),
    **setFiltering** (), **setHorizontalWrapMode** () and
    **setVerticalWrapMode** (). The rendering state is set on the texture
    instance just before it is bound.

    The opaque textured material respects the current matrix and the alpha
    channel of the texture. It will disregard the accumulated opacity in the
    scenegraph.

    A texture material must have a texture set before it is used as a material
    in the scene graph.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#QSGOpaqueTextureMat
        erial

        **QSGOpaqueTextureMaterial::QSGOpaqueTextureMaterial()**

        Creates a new QSGOpaqueTextureMaterial.

        The default mipmap filtering and filtering mode is set to
        **QSGTexture::Nearest** . The default wrap modes is set to
        `QSGTexture::ClampToEdge`.
        """
        ...

    def anisotropyLevel(self) -> QSGTexture.AnisotropyLevel:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#anisotropyLevel

        **QSGTexture::AnisotropyLevel
        QSGOpaqueTextureMaterial::anisotropyLevel() const**

        Returns this material's anistropy level.

        **See also** **setAnisotropyLevel** ().
        """
        ...

    def setAnisotropyLevel(self, level: QSGTexture.AnisotropyLevel) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#setAnisotropyLevel

        **void
        QSGOpaqueTextureMaterial::setAnisotropyLevel(QSGTexture::AnisotropyLevel
        level )**

        Sets this material's anistropy level to **level**.

        **See also** **anisotropyLevel** ().
        """
        ...

    def verticalWrapMode(self) -> QSGTexture.WrapMode:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#verticalWrapMode

        **QSGTexture::WrapMode QSGOpaqueTextureMaterial::verticalWrapMode()
        const**

        Returns this material's vertical wrap mode.

        The default vertical wrap mode is `QSGTexture::ClampToEdge`.

        **See also** **setVerticalWrapMode** ().
        """
        ...

    def setVerticalWrapMode(self, mode: QSGTexture.WrapMode) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#setVerticalWrapMode

        **void
        QSGOpaqueTextureMaterial::setVerticalWrapMode(QSGTexture::WrapMode mode
        )**

        Sets the vertical wrap mode to **mode**.

        The vertical wrap mode is set on the texture instance just before the
        texture is bound for rendering.

        **See also** **verticalWrapMode** ().
        """
        ...

    def horizontalWrapMode(self) -> QSGTexture.WrapMode:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#horizontalWrapMode

        **QSGTexture::WrapMode QSGOpaqueTextureMaterial::horizontalWrapMode()
        const**

        Returns this material's horizontal wrap mode.

        The default horizontal wrap mode is `QSGTexture::ClampToEdge`.

        **See also** **setHorizontalWrapMode** ().
        """
        ...

    def setHorizontalWrapMode(self, mode: QSGTexture.WrapMode) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#setHorizontalWrapMo
        de

        **void
        QSGOpaqueTextureMaterial::setHorizontalWrapMode(QSGTexture::WrapMode
        mode )**

        Sets the horizontal wrap mode to **mode**.

        The horizontal wrap mode is set on the texture instance just before the
        texture is bound for rendering.

        **See also** **horizontalWrapMode** ().
        """
        ...

    def filtering(self) -> QSGTexture.Filtering:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#filtering

        **QSGTexture::Filtering QSGOpaqueTextureMaterial::filtering() const**

        Returns this material's filtering mode.

        The default filtering is `QSGTexture::Nearest`.

        **See also** **setFiltering** ().
        """
        ...

    def setFiltering(self, filtering: QSGTexture.Filtering) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#setFiltering

        **void QSGOpaqueTextureMaterial::setFiltering(QSGTexture::Filtering
        filtering )**

        Sets the filtering to **filtering**.

        The filtering mode is set on the texture instance just before the
        texture is bound for rendering.

        **See also** **filtering** ().
        """
        ...

    def mipmapFiltering(self) -> QSGTexture.Filtering:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#mipmapFiltering

        **QSGTexture::Filtering QSGOpaqueTextureMaterial::mipmapFiltering()
        const**

        Returns this material's mipmap filtering mode.

        The default mipmap mode is `QSGTexture::Nearest`.

        **See also** **setMipmapFiltering** ().
        """
        ...

    def setMipmapFiltering(self, filtering: QSGTexture.Filtering) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#setMipmapFiltering

        **void
        QSGOpaqueTextureMaterial::setMipmapFiltering(QSGTexture::Filtering
        filtering )**

        Sets the mipmap mode to **filtering**.

        The mipmap filtering mode is set on the texture instance just before the
        texture is bound for rendering.

        If the texture does not have mipmapping support, enabling mipmapping has
        no effect.

        **See also** **mipmapFiltering** ().
        """
        ...

    def texture(self) -> QSGTexture:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#texture

        **QSGTexture *QSGOpaqueTextureMaterial::texture() const**

        Returns this texture material's texture.

        **See also** **setTexture** ().
        """
        ...

    def setTexture(self, texture: QSGTexture) -> None:
        """
        https://doc.qt.io/qt-6/qsgopaquetexturematerial.html#setTexture

        **void QSGOpaqueTextureMaterial::setTexture(QSGTexture * texture )**

        Sets the texture of this material to **texture**.

        The material does not take ownership of the texture.

        **See also** **texture** ().
        """
        ...

    def compare(self, other: QSGMaterial) -> int:
        ...

    def createShader(
        self, renderMode: QSGRendererInterface.RenderMode
    ) -> QSGMaterialShader:
        ...

    def type(self) -> QSGMaterialType:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtQuick import *
import enum


class QSGMaterial(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qsgmaterial.html

    **Detailed Description**

    QSGMaterial and **QSGMaterialShader**  subclasses form a tight relationship.
    For one scene graph (including nested graphs), there is one unique
    **QSGMaterialShader**  instance which encapsulates the shaders the scene
    graph uses to render that material, such as a shader to flat coloring of
    geometry. Each **QSGGeometryNode**  can have a unique QSGMaterial containing
    the how the shader should be configured when drawing that node, such as the
    actual color to used to render the geometry.

    QSGMaterial has two virtual functions that both need to be implemented. The
    function **type** () should return a unique instance for all instances of a
    specific subclass. The **createShader** () function should return a new
    instance of **QSGMaterialShader** , specific to that subclass of
    QSGMaterial.

    A minimal QSGMaterial implementation could look like this:

    class Material : public QSGMaterial
        {
        public:
    **QSGMaterialType**  *type() const override { static **QSGMaterialType**
    type; return &type; }
            **QSGMaterialShader**
    *createShader(**QSGRendererInterface** ::RenderMode) const override { return
    new Shader; }
        };

    See the **Custom Material example**  for an introduction on implementing a
    **QQuickItem**  subclass backed by a **QSGGeometryNode**  and a custom
    material.

    **Note:****createShader** () is called only once per **QSGMaterialType** ,
    to reduce redundant work with shader preparation. If a QSGMaterial is backed
    by multiple sets of vertex and fragment shader combinations, the
    implementation of **type** () must return a different, unique
    **QSGMaterialType**  pointer for each combination of shaders.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.

    **See also** **QSGMaterialShader** , **Scene Graph - Custom Material** ,
    **Scene Graph - Two Texture Providers** , and **Scene Graph - Graph** .
    """

    class Flag(enum.Flag):
        Blending: QSGMaterial = ...
        RequiresDeterminant: QSGMaterial = ...
        RequiresFullMatrixExceptTranslate: QSGMaterial = ...
        RequiresFullMatrix: QSGMaterial = ...
        CustomCompileStep: QSGMaterial = ...

    def __init__(self) -> None:
        ...

    def setFlag(self, flags: "QSGMaterial.Flag", enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsgmaterial.html#setFlag

        **void QSGMaterial::setFlag(QSGMaterial::Flags flags , bool on = true)**

        Sets the flags **flags** on this material if **on** is true; otherwise
        clears the attribute.
        """
        ...

    def flags(self) -> "QSGMaterial.Flag":
        """
        https://doc.qt.io/qt-6/qsgmaterial.html#flags

        **QSGMaterial::Flags QSGMaterial::flags() const**

        Returns the material's flags.
        """
        ...

    def compare(self, other: "QSGMaterial") -> int:
        """
        https://doc.qt.io/qt-6/qsgmaterial.html#compare

        **[virtual] int QSGMaterial::compare(const QSGMaterial * other ) const**

        Compares this material to **other** and returns 0 if they are equal; -1
        if this material should sort before **other** and 1 if **other** should
        sort before.

        The scene graph can reorder geometry nodes to minimize state changes.
        The compare function is called during the sorting process so that the
        materials can be sorted to minimize state changes in each call to
        QSGMaterialShader::updateState().

        The this pointer and **other** is guaranteed to have the same **type**
        ().
        """
        ...

    def createShader(
        self, renderMode: "QSGRendererInterface.RenderMode"
    ) -> "QSGMaterialShader":
        """
        https://doc.qt.io/qt-6/qsgmaterial.html#createShader

        **[pure virtual] QSGMaterialShader
        *QSGMaterial::createShader(QSGRendererInterface::RenderMode renderMode )
        const**

        This function returns a new instance of a the **QSGMaterialShader**
        implementation used to render geometry for a specific implementation of
        **QSGMaterial** .

        The function will be called only once for each combination of material
        type and **renderMode** and will be cached internally.

        For most materials, the **renderMode** can be ignored. A few materials
        may need custom handling for specific render modes. For instance if the
        material implements antialiasing in a way that needs to account for
        perspective transformations when RenderMode3D is in use.
        """
        ...

    def type(self) -> "QSGMaterialType":
        """
        https://doc.qt.io/qt-6/qsgmaterial.html#type

        **[pure virtual] QSGMaterialType *QSGMaterial::type() const**

        This function is called by the scene graph to query an identifier that
        is unique to the **QSGMaterialShader**  instantiated by **createShader**
        ().

        For many materials, the typical approach will be to return a pointer to
        a static, and so globally available, **QSGMaterialType**  instance. The
        **QSGMaterialType**  is an opaque object. Its purpose is only to serve
        as a type-safe, simple way to generate unique material identifiers.

        **QSGMaterialType**  *type() const override
            {
                static
        **QSGMaterialType**  type;
                return &type;
            }
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtDBus import *
import enum


class QDBus(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbus.html

    **Detailed Description**
    """

    class CallMode(enum.Enum):
        NoBlock: QDBus = ...
        Block: QDBus = ...
        BlockWithGui: QDBus = ...
        AutoDetect: QDBus = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtWidgets import *
import enum


class QStyleOptionFrame(QStyleOption):
    """
    https://doc.qt.io/qt-6/qstyleoptionframe.html

    **Detailed Description**

    QStyleOptionFrame is used for drawing several built-in Qt widgets, including
    **QFrame** , **QGroupBox** , **QLineEdit** , and **QMenu** .

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    An instance of the QStyleOptionFrame class has **type**  SO_Frame and
    **version**  3.

    The type is used internally by **QStyleOption** , its subclasses, and
    **qstyleoption_cast** () to determine the type of style option. In general
    you do not need to worry about this unless you want to create your own
    **QStyleOption**  subclass and your own styles. The version is used by
    **QStyleOption**  subclasses to implement extensions without breaking
    compatibility. If you use **qstyleoption_cast** (), you normally do not need
    to check it.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOption** .
    """

    class FrameFeature(enum.Flag):
        None_: QStyleOptionFrame = ...
        Flat: QStyleOptionFrame = ...
        Rounded: QStyleOptionFrame = ...

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionFrame = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionFrame = ...

    features = ...
    frameShape: QFrame = ...
    lineWidth: int = ...
    midLineWidth: int = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionframe.html#QStyleOptionFrame

        **QStyleOptionFrame::QStyleOptionFrame()**

        Constructs a QStyleOptionFrame, initializing the members variables to
        their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionFrame") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionframe.html#QStyleOptionFrame-1

        **QStyleOptionFrame::QStyleOptionFrame(const QStyleOptionFrame & other
        )**

        Constructs a copy of the **other** style option.
        """
        ...
